package com.ruoyi.ss.recordBalance.mapper;

import java.util.List;
import com.ruoyi.ss.recordBalance.domain.RecordBalance;
import com.ruoyi.ss.recordBalance.domain.RecordBalanceVO;
import com.ruoyi.ss.recordBalance.domain.RecordBalanceQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 余额变动记录Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-22
 */
public interface RecordBalanceMapper
{
    /**
     * 查询余额变动记录
     *
     * @param id 余额变动记录主键
     * @return 余额变动记录
     */
    public RecordBalanceVO selectRecordBalanceById(Long id);

    /**
     * 查询余额变动记录列表
     *
     * @param recordBalance 余额变动记录
     * @return 余额变动记录集合
     */
    public List<RecordBalanceVO> selectRecordBalanceList(@Param("query")RecordBalanceQuery recordBalance);

    /**
     * 新增余额变动记录
     *
     * @param recordBalance 余额变动记录
     * @return 结果
     */
    public int insertRecordBalance(RecordBalance recordBalance);

    /**
     * 修改余额变动记录
     *
     * @param recordBalance 余额变动记录
     * @return 结果
     */
    public int updateRecordBalance(@Param("data") RecordBalance recordBalance);

    /**
     * 删除余额变动记录
     *
     * @param id 余额变动记录主键
     * @return 结果
     */
    public int deleteRecordBalanceById(Long id);

    /**
     * 批量删除余额变动记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordBalanceByIds(Long[] ids);

    /**
     * 查询一个
     */
    RecordBalanceVO selectOne(@Param("query") RecordBalanceQuery query);
}
